# Generated by Django 5.2.8 on 2026-02-16 16:21

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("notices", "0007_alter_notificationtemplate_contact_roles_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="maintenance",
            name="end",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="maintenance",
            name="start",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="maintenance",
            name="status",
            field=models.CharField(db_index=True, max_length=30),
        ),
        migrations.AlterField(
            model_name="outage",
            name="end",
            field=models.DateTimeField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="outage",
            name="start",
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="outage",
            name="status",
            field=models.CharField(db_index=True, max_length=30),
        ),
    ]
