"""
Constants for vendor notification plugin configuration
"""

# Default allowed content types for impact linking
DEFAULT_ALLOWED_CONTENT_TYPES = [
    "circuits.Circuit",
    "dcim.Device",
    "dcim.PowerFeed",
    "dcim.Site",
]
