# Generated by Django 5.2.8 on 2026-01-27
# Renames MessageTemplate -> NotificationTemplate, PreparedMessage -> PreparedNotification

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("notices", "0005_messagetemplate_preparedmessage_templatescope"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="MessageTemplate",
            new_name="NotificationTemplate",
        ),
        migrations.RenameModel(
            old_name="PreparedMessage",
            new_name="PreparedNotification",
        ),
        migrations.CreateModel(
            name="SentNotification",
            fields=[],
            options={
                "proxy": True,
                "verbose_name": "Sent Notification",
                "verbose_name_plural": "Sent Notifications",
            },
            bases=("notices.preparednotification",),
        ),
    ]
