# Generated by Django 5.2.8 on 2026-01-28 19:38

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("notices", "0006_rename_messaging_models"),
        ("tenancy", "0020_remove_contactgroupmembership"),
    ]

    operations = [
        migrations.AlterField(
            model_name="notificationtemplate",
            name="contact_roles",
            field=models.ManyToManyField(blank=True, related_name="notification_templates", to="tenancy.contactrole"),
        ),
        migrations.AlterField(
            model_name="preparednotification",
            name="contacts",
            field=models.ManyToManyField(blank=True, related_name="prepared_notifications", to="tenancy.contact"),
        ),
        migrations.AlterField(
            model_name="preparednotification",
            name="template",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="prepared_notifications",
                to="notices.notificationtemplate",
            ),
        ),
    ]
